# tpdk-safe-checkout
Simple, yet elegant web interfaces for your convenience. One request away from your first secured C2C transaction.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.10
- Package version: 2.0.10
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://tripartie.com](https://tripartie.com)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/tripartie/tpdk-safe-checkout.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/tripartie/tpdk-safe-checkout.git`)

Then import the package:
```python
import tpdk_safe_checkout
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tpdk_safe_checkout
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import tpdk_safe_checkout
from tpdk_safe_checkout.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://staging-api.tripartie.app
# See configuration.py for a list of all supported configuration parameters.
configuration = tpdk_safe_checkout.Configuration(
    host = "https://staging-api.tripartie.app"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: jwtPersonalKey
configuration.api_key['jwtPersonalKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['jwtPersonalKey'] = 'Bearer'


# Enter a context with an instance of the API client
with tpdk_safe_checkout.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tpdk_safe_checkout.BrandingApi(api_client)
    id = 'id_example' # str | Organization identifier
    organization_update = tpdk_safe_checkout.OrganizationUpdate() # OrganizationUpdate | The updated Organization resource

    try:
        # Update your Organization details, branding or parameters
        api_response = api_instance.api_organizations_id_patch(id, organization_update)
        print("The response of BrandingApi->api_organizations_id_patch:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BrandingApi->api_organizations_id_patch: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://staging-api.tripartie.app*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BrandingApi* | [**api_organizations_id_patch**](docs/BrandingApi.md#api_organizations_id_patch) | **PATCH** /organizations/{id} | Update your Organization details, branding or parameters
*BrandingApi* | [**api_organizations_idicon_delete**](docs/BrandingApi.md#api_organizations_idicon_delete) | **DELETE** /organizations/{id}/icon | Unset your Organization Icon
*BrandingApi* | [**api_organizations_idicon_post**](docs/BrandingApi.md#api_organizations_idicon_post) | **POST** /organizations/{id}/icon | Upload your Organization Icon
*BrandingApi* | [**api_organizations_idlogo_delete**](docs/BrandingApi.md#api_organizations_idlogo_delete) | **DELETE** /organizations/{id}/logo | Unset your Organization Logo
*BrandingApi* | [**api_organizations_idlogo_post**](docs/BrandingApi.md#api_organizations_idlogo_post) | **POST** /organizations/{id}/logo | Upload your Organization logo
*NotificationApi* | [**api_personas_idnotifications_get_collection**](docs/NotificationApi.md#api_personas_idnotifications_get_collection) | **GET** /personas/{id}/notifications | Retrieve pending notifications for Persona
*NotificationApi* | [**api_personas_persona_idnotifications_id_patch**](docs/NotificationApi.md#api_personas_persona_idnotifications_id_patch) | **PATCH** /personas/{personaId}/notifications/{id} | Mark as read/unread a notification for Persona
*NotificationApi* | [**api_users_idnotifications_get_collection**](docs/NotificationApi.md#api_users_idnotifications_get_collection) | **GET** /users/{id}/notifications | Retrieves the collection of Notification resources.
*NotificationApi* | [**api_users_user_idnotifications_id_patch**](docs/NotificationApi.md#api_users_user_idnotifications_id_patch) | **PATCH** /users/{userId}/notifications/{id} | Mark as read/unread a notification for User
*OrganizationApi* | [**api_organizations_get_collection**](docs/OrganizationApi.md#api_organizations_get_collection) | **GET** /organizations | Retrieves the collection of Organization resources.
*OrganizationApi* | [**api_organizations_id_get**](docs/OrganizationApi.md#api_organizations_id_get) | **GET** /organizations/{id} | Retrieves a Organization resource.
*PersonaApi* | [**api_personas_get_collection**](docs/PersonaApi.md#api_personas_get_collection) | **GET** /personas | Retrieves the collection of Persona resources.
*PersonaApi* | [**api_personas_id_delete**](docs/PersonaApi.md#api_personas_id_delete) | **DELETE** /personas/{id} | Unregister a Persona (Your customer)
*PersonaApi* | [**api_personas_id_get**](docs/PersonaApi.md#api_personas_id_get) | **GET** /personas/{id} | Retrieves a Persona resource.
*PersonaApi* | [**api_personas_id_patch**](docs/PersonaApi.md#api_personas_id_patch) | **PATCH** /personas/{id} | Updates the Persona resource.
*PersonaApi* | [**api_personas_post**](docs/PersonaApi.md#api_personas_post) | **POST** /personas | Register a Persona (Your customer)
*SafeCheckoutApi* | [**api_offers_get_collection**](docs/SafeCheckoutApi.md#api_offers_get_collection) | **GET** /offers | Search amongst Offers
*SafeCheckoutApi* | [**api_offers_post**](docs/SafeCheckoutApi.md#api_offers_post) | **POST** /offers | Create a public link for Offer
*SafeCheckoutApi* | [**api_offers_ulid_get**](docs/SafeCheckoutApi.md#api_offers_ulid_get) | **GET** /offers/{ulid} | Fetch a Offer details
*SafeCheckoutApi* | [**api_offers_ulid_patch**](docs/SafeCheckoutApi.md#api_offers_ulid_patch) | **PATCH** /offers/{ulid} | Update existing Offer
*SafeCheckoutApi* | [**api_offers_ulidmedias_id_delete**](docs/SafeCheckoutApi.md#api_offers_ulidmedias_id_delete) | **DELETE** /offers/{ulid}/medias/{id} | Removes the Media resource.
*SafeCheckoutApi* | [**api_offers_ulidmedias_post**](docs/SafeCheckoutApi.md#api_offers_ulidmedias_post) | **POST** /offers/{ulid}/medias | Upload a picture for a given Offer
*SafeCheckoutApi* | [**api_transactions_ulidevaluations_post**](docs/SafeCheckoutApi.md#api_transactions_ulidevaluations_post) | **POST** /transactions/{ulid}/evaluations | Submit an Evaluation for the Transaction
*SafeCheckoutApi* | [**api_transactions_ulidparcels_get_collection**](docs/SafeCheckoutApi.md#api_transactions_ulidparcels_get_collection) | **GET** /transactions/{ulid}/parcels | Retrieves the collection of Parcel resources.
*SafeCheckoutApi* | [**api_transactions_ulidparcels_id_delete**](docs/SafeCheckoutApi.md#api_transactions_ulidparcels_id_delete) | **DELETE** /transactions/{ulid}/parcels/{id} | Removes the Parcel resource.
*SafeCheckoutApi* | [**api_transactions_ulidparcels_post**](docs/SafeCheckoutApi.md#api_transactions_ulidparcels_post) | **POST** /transactions/{ulid}/parcels | Creates a Parcel resource.
*UserApi* | [**api_api_clients_get_collection**](docs/UserApi.md#api_api_clients_get_collection) | **GET** /api-clients | Retrieves the collection of ApiClient resources.
*UserApi* | [**api_api_clients_identifier_delete**](docs/UserApi.md#api_api_clients_identifier_delete) | **DELETE** /api-clients/{identifier} | Removes the ApiClient resource.
*UserApi* | [**api_api_clients_identifier_get**](docs/UserApi.md#api_api_clients_identifier_get) | **GET** /api-clients/{identifier} | Retrieves a ApiClient resource.
*UserApi* | [**api_api_clients_post**](docs/UserApi.md#api_api_clients_post) | **POST** /api-clients | Creates a ApiClient resource.
*UserApi* | [**api_invite_post**](docs/UserApi.md#api_invite_post) | **POST** /invite | Organization invite
*UserApi* | [**api_me_get**](docs/UserApi.md#api_me_get) | **GET** /me | Retrieves a User resource.
*UserApi* | [**api_register_post**](docs/UserApi.md#api_register_post) | **POST** /register | Customer onboarding
*UserApi* | [**api_users_get_collection**](docs/UserApi.md#api_users_get_collection) | **GET** /users | Retrieves the collection of User resources.
*UserApi* | [**api_users_id_delete**](docs/UserApi.md#api_users_id_delete) | **DELETE** /users/{id} | Removes the User resource.
*UserApi* | [**api_users_id_get**](docs/UserApi.md#api_users_id_get) | **GET** /users/{id} | Retrieves a User resource.
*UserApi* | [**api_users_id_patch**](docs/UserApi.md#api_users_id_patch) | **PATCH** /users/{id} | Updates the User resource.
*UserApi* | [**api_users_idavatar_delete**](docs/UserApi.md#api_users_idavatar_delete) | **DELETE** /users/{id}/avatar | Unset your personal avatar
*UserApi* | [**api_users_idavatar_post**](docs/UserApi.md#api_users_idavatar_post) | **POST** /users/{id}/avatar | Upload your personal avatar
*UserApi* | [**api_users_idemail_patch**](docs/UserApi.md#api_users_idemail_patch) | **PATCH** /users/{id}/email | Update user email
*UserApi* | [**api_users_idemail_validation_patch**](docs/UserApi.md#api_users_idemail_validation_patch) | **PATCH** /users/{id}/email-validation | Validate email ownership
*UserApi* | [**api_users_idenable_patch**](docs/UserApi.md#api_users_idenable_patch) | **PATCH** /users/{id}/enable | Updates the User resource.
*UserApi* | [**api_users_idpassword_patch**](docs/UserApi.md#api_users_idpassword_patch) | **PATCH** /users/{id}/password | Updates the User resource.
*UserApi* | [**api_users_idtotp_setup_patch**](docs/UserApi.md#api_users_idtotp_setup_patch) | **PATCH** /users/{id}/totp-setup | Updates the User resource.
*UserApi* | [**api_users_idtotp_toggle_patch**](docs/UserApi.md#api_users_idtotp_toggle_patch) | **PATCH** /users/{id}/totp-toggle | Updates the User resource.
*UserApi* | [**authentication_post**](docs/UserApi.md#authentication_post) | **POST** /authentication | User authentication
*WebhookApi* | [**api_webhook_histories_get_collection**](docs/WebhookApi.md#api_webhook_histories_get_collection) | **GET** /webhook-histories | Retrieves the collection of WebhookHistory resources.
*WebhookApi* | [**api_webhook_histories_id_get**](docs/WebhookApi.md#api_webhook_histories_id_get) | **GET** /webhook-histories/{id} | Retrieves a WebhookHistory resource.
*WebhookApi* | [**api_webhook_histories_id_put**](docs/WebhookApi.md#api_webhook_histories_id_put) | **PUT** /webhook-histories/{id} | Replay a Webhook that ended up in failure
*WebhookApi* | [**api_webhook_subscriptions_get_collection**](docs/WebhookApi.md#api_webhook_subscriptions_get_collection) | **GET** /webhook-subscriptions | Retrieves the collection of WebhookSubscription resources.
*WebhookApi* | [**api_webhook_subscriptions_id_delete**](docs/WebhookApi.md#api_webhook_subscriptions_id_delete) | **DELETE** /webhook-subscriptions/{id} | Removes the WebhookSubscription resource.
*WebhookApi* | [**api_webhook_subscriptions_post**](docs/WebhookApi.md#api_webhook_subscriptions_post) | **POST** /webhook-subscriptions | Subscribe to Event(s)


## Documentation For Models

 - [AccessError](docs/AccessError.md)
 - [Address](docs/Address.md)
 - [ApiClientPostCreationRead](docs/ApiClientPostCreationRead.md)
 - [ApiClientRead](docs/ApiClientRead.md)
 - [ApiClientWrite](docs/ApiClientWrite.md)
 - [AuthError](docs/AuthError.md)
 - [BankAccountUserRead](docs/BankAccountUserRead.md)
 - [EvaluationRead](docs/EvaluationRead.md)
 - [EvaluationWrite](docs/EvaluationWrite.md)
 - [GenericError](docs/GenericError.md)
 - [InvalidQueryError](docs/InvalidQueryError.md)
 - [Media](docs/Media.md)
 - [MediaRead](docs/MediaRead.md)
 - [MediaUserRead](docs/MediaUserRead.md)
 - [MessageError](docs/MessageError.md)
 - [Metadata](docs/Metadata.md)
 - [NotFoundError](docs/NotFoundError.md)
 - [NotificationRead](docs/NotificationRead.md)
 - [NotificationUpdate](docs/NotificationUpdate.md)
 - [OfferAddressIndependentWrite](docs/OfferAddressIndependentWrite.md)
 - [OfferCollectionRead](docs/OfferCollectionRead.md)
 - [OfferIndependentWrite](docs/OfferIndependentWrite.md)
 - [OfferMediaRead](docs/OfferMediaRead.md)
 - [OfferMetadataIndependentWrite](docs/OfferMetadataIndependentWrite.md)
 - [OfferMetadataUpdate](docs/OfferMetadataUpdate.md)
 - [OfferOrganizationRead](docs/OfferOrganizationRead.md)
 - [OfferPersonaIndependentWrite](docs/OfferPersonaIndependentWrite.md)
 - [OfferPostCreationRead](docs/OfferPostCreationRead.md)
 - [OfferRead](docs/OfferRead.md)
 - [OfferUpdate](docs/OfferUpdate.md)
 - [OrganizationAddressUpdate](docs/OrganizationAddressUpdate.md)
 - [OrganizationCollectionRead](docs/OrganizationCollectionRead.md)
 - [OrganizationMediaCollectionRead](docs/OrganizationMediaCollectionRead.md)
 - [OrganizationMediaRead](docs/OrganizationMediaRead.md)
 - [OrganizationRead](docs/OrganizationRead.md)
 - [OrganizationUpdate](docs/OrganizationUpdate.md)
 - [OrganizationUserRead](docs/OrganizationUserRead.md)
 - [Parcel](docs/Parcel.md)
 - [ParcelWrite](docs/ParcelWrite.md)
 - [Persona](docs/Persona.md)
 - [PersonaAddressRead](docs/PersonaAddressRead.md)
 - [PersonaAddressUpdate](docs/PersonaAddressUpdate.md)
 - [PersonaAddressWrite](docs/PersonaAddressWrite.md)
 - [PersonaCollectionRead](docs/PersonaCollectionRead.md)
 - [PersonaMetadataRead](docs/PersonaMetadataRead.md)
 - [PersonaMetadataUpdate](docs/PersonaMetadataUpdate.md)
 - [PersonaMetadataWrite](docs/PersonaMetadataWrite.md)
 - [PersonaRead](docs/PersonaRead.md)
 - [PersonaUpdate](docs/PersonaUpdate.md)
 - [PersonaWrite](docs/PersonaWrite.md)
 - [RateLimitError](docs/RateLimitError.md)
 - [UnprocessableEntity](docs/UnprocessableEntity.md)
 - [UnprocessableEntityViolationsInner](docs/UnprocessableEntityViolationsInner.md)
 - [UserAuthenticatedRead](docs/UserAuthenticatedRead.md)
 - [UserBankAccountAuthenticatedRead](docs/UserBankAccountAuthenticatedRead.md)
 - [UserCollectionRead](docs/UserCollectionRead.md)
 - [UserEmailValidationWrite](docs/UserEmailValidationWrite.md)
 - [UserInvite](docs/UserInvite.md)
 - [UserJwtCreated](docs/UserJwtCreated.md)
 - [UserJwtWrite](docs/UserJwtWrite.md)
 - [UserMediaAuthenticatedRead](docs/UserMediaAuthenticatedRead.md)
 - [UserMediaCollectionRead](docs/UserMediaCollectionRead.md)
 - [UserMediaRead](docs/UserMediaRead.md)
 - [UserMediaSupportRead](docs/UserMediaSupportRead.md)
 - [UserOrganizationAuthenticatedRead](docs/UserOrganizationAuthenticatedRead.md)
 - [UserOrganizationCollectionRead](docs/UserOrganizationCollectionRead.md)
 - [UserOrganizationRead](docs/UserOrganizationRead.md)
 - [UserOrganizationSupportRead](docs/UserOrganizationSupportRead.md)
 - [UserPostRegisterRead](docs/UserPostRegisterRead.md)
 - [UserSupportRead](docs/UserSupportRead.md)
 - [UserTotpSetupRead](docs/UserTotpSetupRead.md)
 - [UserTotpToggleWrite](docs/UserTotpToggleWrite.md)
 - [UserUpdate](docs/UserUpdate.md)
 - [UserUserEmailUpdate](docs/UserUserEmailUpdate.md)
 - [UserUserPasswordUpdate](docs/UserUserPasswordUpdate.md)
 - [UserUserRead](docs/UserUserRead.md)
 - [UserUserSubscribed](docs/UserUserSubscribed.md)
 - [UserWrite](docs/UserWrite.md)
 - [View](docs/View.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookHistoryCollectionRead](docs/WebhookHistoryCollectionRead.md)
 - [WebhookHistoryRead](docs/WebhookHistoryRead.md)
 - [WebhookObject](docs/WebhookObject.md)
 - [WebhookSubscriptionRead](docs/WebhookSubscriptionRead.md)
 - [WebhookSubscriptionWrite](docs/WebhookSubscriptionWrite.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="oauth"></a>
### oauth

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **OFFER_READ**: Read-only operations on safe-checkout offers
 - **OFFER_WRITE**: Write permissions on safe-checkout offers
 - **ORGANIZATION_READ**: Read organization details and stats
 - **PERSONA_READ**: Read operations on the shared user-base knowledge
 - **PERSONA_WRITE**: Write permissions on the shared user-base knowledge
 - **PERSONA_AUTH**: Capability to issue short-term lived authenticated URL

<a id="jwtPersonalKey"></a>
### jwtPersonalKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="personaAuthKey"></a>
### personaAuthKey

- **Type**: API key
- **API key parameter name**: X-Persona-Authorization
- **Location**: HTTP header


## Author

noc@tripartie.com


